==> fbreader-sources-0.8.7.tgz: fbreader-0.8.7/fbreader/src/optionsDialog/ConfigPage.cpp <==
/*
 * FBReader -- electronic book reader
 * Copyright (C) 2004-2007 Nikolay Pultsin <geometer@mawhrin.net>
 * Copyright (C) 2005 Mikhail Sobolev <mss@mawhrin.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#include <ZLOptionEntry.h>
#include <ZLOptionsDialog.h>

#include <optionEntries/ZLToggleBooleanOptionEntry.h>

#include "ConfigPage.h"

#include "../fbreader/FBReader.h"

class TimeoutEntry : public ZLSimpleSpinOptionEntry {

public:
	TimeoutEntry(ZLIntegerRangeOption &option);
	void onAccept(int value);
};

TimeoutEntry::TimeoutEntry(ZLIntegerRangeOption &option) : ZLSimpleSpinOptionEntry(option, 5) {
}

void TimeoutEntry::onAccept(int value) {
	ZLOption::startAutoSave(isVisible() ? value : 0);
	ZLSimpleSpinOptionEntry::onAccept(value);
}

ConfigPage::ConfigPage(FBReader &fbreader, ZLDialogContent &dialogTab) {
	ZLToggleBooleanOptionEntry *enableEntry =
		new ZLToggleBooleanOptionEntry(fbreader.ConfigAutoSavingOption);
	dialogTab.addOption(ZLResourceKey("autoSave"), enableEntry);

	ZLOptionEntry *timeoutEntry = new TimeoutEntry(fbreader.ConfigAutoSaveTimeoutOption);
	enableEntry->addDependentEntry(timeoutEntry);
	dialogTab.addOption(ZLResourceKey("timeout"), timeoutEntry);

	enableEntry->onStateChanged(enableEntry->initialState());
}

==> fbreader-sources-0.12.1.tgz: fbreader-0.12.1/fbreader/src/optionsDialog/ConfigPage.cpp <==
/*
 * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#include <ZLOptionEntry.h>
#include <ZLOptionsDialog.h>

#include <optionEntries/ZLToggleBooleanOptionEntry.h>

#include "ConfigPage.h"

#include "../fbreader/FBReader.h"

class TimeoutEntry : public ZLSimpleSpinOptionEntry {

public:
	TimeoutEntry(ZLIntegerRangeOption &option);
	void onAccept(int value);
};

TimeoutEntry::TimeoutEntry(ZLIntegerRangeOption &option) : ZLSimpleSpinOptionEntry(option, 5) {
}

void TimeoutEntry::onAccept(int value) {
	ZLOption::startAutoSave(isVisible() ? value : 0);
	ZLSimpleSpinOptionEntry::onAccept(value);
}

ConfigPage::ConfigPage(ZLDialogContent &dialogTab) {
	FBReader &fbreader = FBReader::Instance();
	ZLToggleBooleanOptionEntry *enableEntry =
		new ZLToggleBooleanOptionEntry(fbreader.ConfigAutoSavingOption);
	dialogTab.addOption(ZLResourceKey("autoSave"), enableEntry);

	ZLOptionEntry *timeoutEntry = new TimeoutEntry(fbreader.ConfigAutoSaveTimeoutOption);
	enableEntry->addDependentEntry(timeoutEntry);
	dialogTab.addOption(ZLResourceKey("timeout"), timeoutEntry);

	enableEntry->onStateChanged(enableEntry->initialState());
}
